@@ -143,7 +143,7 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     df_leads_clean = df.copy()
 
     nna = df_leads_clean.isna().sum()
-    logging.info( f"NA in original dataframe:" )
+    logging.info( "NA in original dataframe:" )
     logging.info( f"{nna}" )
 
     df_leads_clean,imp = preprocessing_training_common( df=df_leads_clean,
@@ -165,7 +165,7 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     df_leads_clean = devutils.set_target_column(df=df_leads_clean,model_type=model_type,multiplier=multiplier)
 
     nna = df_leads_clean.isna().sum()
-    logging.info( f"NA in final dataframe:" )
+    logging.info( "NA in final dataframe:" )
     logging.info( f"{nna}" )
 
     return df_leads_clean,imp
