@@ -275,27 +275,6 @@ def create_company_years_column(df):
     df['CompanyYears']= CurrentYear-df['YearFounded']
     df.loc[(df['CompanyYears'] < 0) | (df['CompanyYears'] > 150),'CompanyYears'] = np.nan
     logger.info(df['CompanyYears'].value_counts())
-
-
-    # df.loc[(CurrentYear - df['YearFounded'] <= 2),
-    #        'CompanyYears'] = "0-2 Years"
-    # df.loc[(CurrentYear - df['YearFounded'] > 2) & (
-    #     CurrentYear - df['YearFounded'] <= 5), 'CompanyYears'] = "0-2 Years"
-    # df.loc[(CurrentYear - df['YearFounded'] > 2) & (
-    #     CurrentYear - df['YearFounded'] <= 5), 'CompanyYears'] = "3-5 Years"
-    # df.loc[(CurrentYear - df['YearFounded'] > 5) & (
-    #     CurrentYear - df['YearFounded'] <= 10), 'CompanyYears'] = "6-10 Years"
-    # df.loc[(CurrentYear - df['YearFounded'] > 10) & (
-    #     CurrentYear - df['YearFounded'] <= 25), 'CompanyYears'] = "11-25 Years"
-    # df.loc[(CurrentYear - df['YearFounded'] > 25) & (
-    #     CurrentYear - df['YearFounded'] <= 50), 'CompanyYears'] = "26-50 Years"
-    # df.loc[(CurrentYear - df['YearFounded'] > 50),
-    #        'CompanyYears'] = "51+ Years"
-    # # Errors go to "unknown category"
-    # df.loc[(df['YearFounded'] > CurrentYear) | (
-    #     df['YearFounded'] < 1600), 'CompanyYears'] = "Unknown"
-
-
     df = df.drop(['YearFounded'], axis=1)
     return df
 
@@ -322,6 +301,9 @@ def filter_countries(df, countries,fixed_filter):
     if fixed_filter==1:
         logger.info(f'countries out of top 8 go to other')
         top = df['Country'].value_counts().head(8).index.tolist()
+
+        logger.info('countries out of top 10 go to other')
+        top = df['Country'].value_counts().head(10).index.tolist()
         df.loc[~df['Country'].isin(top),'Country'] = 'other'
 
     else:
@@ -338,20 +320,12 @@ def process_bulkstatus(df):
         df.loc[(df['BulkStatus'] == 6), 'is_OOO'] = 1
         df['is_NN']=0
         df.loc[(df['BulkStatus'] == 12), 'is_NN'] = 1
-        df['is_New']=0
-        df.loc[(df['BulkStatus'] == 0), 'is_New'] = 1        
-        df['is_FU']=0
-        df.loc[(df['BulkStatus'] == 2), 'is_FU'] = 1        
         df.drop(labels=['BulkStatus'],axis=1,inplace=True)
         logger.info('Deleted BulkStatus column')
         logger.info('OOO')
         logger.info(df['is_OOO'].value_counts())
         logger.info('NN')
         logger.info(df['is_NN'].value_counts())
-        logger.info('New')
-        logger.info(df['is_New'].value_counts())
-        logger.info('FU')
-        logger.info(df['is_FU'].value_counts())
     else:
         logger.info('Column not present')
     return df
@@ -376,15 +350,15 @@ def convert_kwkey_specialties_and_technologies_to_int(df):
     Returns:
        df [dataframe]: [Dataframe with the leads]
     """
-    logger.info(f'Counting KeyWords')
+    logger.info('Counting KeyWords')
     # number of elements in kw_key
     df['Nkw_key'] = df.kw_key.apply(
         lambda x: 0 if pd.isnull(x) else len(re.findall("(?:\".*?\"|\S)+", x)))
     # Number of elements in technologies
-    logger.info( f'Counting Technologies' )
+    logger.info('Counting Technologies')
     df['NTechnologies'] = df.Technologies.apply(
         lambda x: 0 if pd.isnull(x) else len(re.split(',', x)))
-    logger.info( f'Counting Specialties' )
+    logger.info('Counting Specialties')
     df['NSpecialties'] = df.Technologies.apply(
         lambda x: 0 if pd.isnull(x) else len(re.split(',', x)))
 
@@ -423,7 +397,7 @@ def fill_variables(df):
 def impute_nas_and_save_imputer(df,columns_to_impute):
     df_impute = df[columns_to_impute]
     logger.info(f"Imputing NAs in {columns_to_impute}")
-    logger.info(f"NAs in DataFrame before imputation:")
+    logger.info("NAs in DataFrame before imputation:")
     nna = df_impute.isna().sum()
     logger.info(f"{nna}")
 
@@ -440,7 +414,7 @@ def impute_nas_and_save_imputer(df,columns_to_impute):
     df_impute = pd.DataFrame(data=imp.transform(df_impute),
                              columns=df_impute.columns)
 
-    logger.info(f"NAs in DataFrame after imputation:")
+    logger.info("NAs in DataFrame after imputation:")
     nna = df_impute.isna().sum()
     logger.info(f"{nna}")
 
@@ -465,7 +439,7 @@ def impute_nas(df,columns_to_impute,imp):
     """
     df_impute = df[columns_to_impute]
     logger.info(f"Imputing NAs in {columns_to_impute}")
-    logger.info(f"NAs in DataFrame before imputation:")
+    logger.info("NAs in DataFrame before imputation:")
     nna = df_impute.isna().sum()
     logger.info(f"{nna}")
     # Instance the imputer if it is not created
@@ -474,7 +448,7 @@ def impute_nas(df,columns_to_impute,imp):
     df_impute = pd.DataFrame(data=imp.transform(df_impute),
                              columns=df_impute.columns)
 
-    logger.info(f"NAs in DataFrame after imputation:")
+    logger.info("NAs in DataFrame after imputation:")
     nna = df_impute.isna().sum()
     logger.info(f"{nna}")
 
